#
# spec file for package findbugs
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global noupdatechecks_version 20140707gitcce19ac
Name:           findbugs
Version:        3.0.1
Release:        3.1
Summary:        Bug pattern detector for Java
License:        LGPL-2.1-or-later
Group:          Development/Languages/Java
URL:            http://findbugs.sourceforge.net/
Source0:        http://downloads.sourceforge.net/%{name}/%{name}-%{version}-source.zip
Source1:        findbugs-ant
Source2:        findbugs-tools-README
Source3:        http://repo1.maven.org/maven2/com/google/code/findbugs/findbugs/3.0.1/findbugs-3.0.1.pom
Source4:        http://repo1.maven.org/maven2/com/google/code/findbugs/annotations/3.0.0/annotations-3.0.0.pom
# This archive contains the source for the noUpdateChecks plugin.
# It was created with:
#   $ git clone --bare git@github.com:findbugsproject/findbugs
#   $ git --git-dir=findbugs.git archive --format tgz cce19ac plugins/noUpdateChecks -o noUpdateChecks-plugin-20140707gitcce19ac.tgz
Source5:        noUpdateChecks-plugin-%{noupdatechecks_version}.tgz
Source6:        http://repo1.maven.org/maven2/com/google/code/findbugs/findbugs-ant/3.0.0/findbugs-ant-3.0.0.pom
Source10:       findbugs-16x16.png
Source11:       findbugs-32x32.png
Source12:       findbugs-48x48.png
Source13:       findbugs.desktop
Patch0:         findbugs-build.patch
Patch1:         findbugs-home.patch
# Allow Ant task to work even though findbugs.jar has no Class-Path attribute in its manifest (bug #1080682)
Patch2:         findbugs-ant-task-classpath.patch
Patch3:         findbugs-manual.patch
# Port to dom4j 2.0
Patch4:         findbugs-dom4j.patch
Patch5:         findbugs-jdk11.patch
Patch6:         findbugs-javadoc.patch
Patch7:         reproducible-now.patch
BuildRequires:  ant
BuildRequires:  apache-commons-lang
BuildRequires:  desktop-file-utils
BuildRequires:  docbook-xsl-stylesheets
BuildRequires:  dom4j
BuildRequires:  fdupes
BuildRequires:  findbugs-bcel
BuildRequires:  hicolor-icon-theme
BuildRequires:  java-devel
BuildRequires:  javapackages-local
BuildRequires:  jaxen
BuildRequires:  jcip-annotations
BuildRequires:  jdepend
BuildRequires:  jformatstring
BuildRequires:  jpackage-utils
BuildRequires:  jsr-305
BuildRequires:  junit
# For generating HTML version of manual using xsltproc
BuildRequires:  libxslt
BuildRequires:  make
BuildRequires:  objectweb-asm
BuildRequires:  texlive-preprint
BuildRequires:  unzip
BuildRequires:  update-desktop-files
BuildRequires:  tex(latex)
Requires:       apache-commons-lang
Requires:       dom4j
Requires:       findbugs-bcel
Requires:       java
Requires:       jaxen
Requires:       jcip-annotations
Requires:       jformatstring
Requires:       jpackage-utils
Requires:       jsr-305
Requires:       junit
Requires:       objectweb-asm
BuildArch:      noarch

%description
Findbugs is a program which uses static analysis to look for bugs in Java code.
It can check for null pointer exceptions, multithreaded code errors, and other
bugs.

%package -n ant-findbugs
Summary:        Ant task for findbugs
Group:          Development/Languages/Java
Requires:       %{name} = %{version}-%{release}
Requires:       ant
Provides:       %{name}:%{_sysconfdir}/ant.d/%{name}

%description -n ant-findbugs
This package defines an ant task for findbugs for easy integration of findbugs
into your ant-controlled project.

%package javadoc
Summary:        Javadoc documentation for findbugs
Group:          Documentation/HTML

%description javadoc
Javadoc documentation for findbugs.

%package tools
Summary:        Addon tools for findbugs
Group:          Development/Languages/Java
Requires:       %{name} = %{version}-%{release}
Requires:       junit

%description tools
This package contains additional tools for use with findbugs.  See
README.tools for more information.

%prep
%setup -q
%setup -q -a 5
%patch0 -p1
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p1
%patch5 -p1
%patch6 -p1
%patch7 -p1

cp -p %{SOURCE2} README.tools

# Make sure we don't accidentally use any existing JAR files
rm -f lib/*.jar

# Get rid of code for Mac OS X that depends on a jar from Apple
rm -f src/gui/edu/umd/cs/findbugs/gui2/OSXAdapter.java
%pom_remove_dep com.apple:AppleJavaExtensions %{SOURCE3}

%build
# Build the class files and docs
ant docs build

# Build the javadocs
ant apiJavadoc

# Build the architecture PDF
pushd design/architecture
make %{?_smp_mflags} depend
make %{?_smp_mflags}
popd

# Package up the tools
pushd build/classes
jar cf ../../lib/findbugs-tools.jar edu/umd/cs/findbugs/tools
popd

# Build the noUpdateChecks plugin
pushd plugins/noUpdateChecks
ant plugin-jar
popd

%install
# Install the jars
mkdir -p %{buildroot}%{_javadir}
cp -p lib/annotations.jar %{buildroot}%{_javadir}/%{name}-annotations.jar
cp -p lib/%{name}-tools.jar %{buildroot}%{_javadir}/%{name}-tools.jar
cp -p lib/%{name}.jar %{buildroot}%{_javadir}/%{name}.jar

# Install the ant task
mkdir -p %{buildroot}%{_javadir}/ant
cp -p lib/%{name}-ant.jar %{buildroot}%{_javadir}/ant/ant-%{name}.jar
mkdir -p %{buildroot}%{_sysconfdir}/ant.d
cp -p %{SOURCE1} %{buildroot}%{_sysconfdir}/ant.d/%{name}

# Install the javadocs
mkdir -p %{buildroot}%{_javadocdir}
cp -a apiJavaDoc %{buildroot}%{_javadocdir}/%{name}

# Install the scripts
mkdir -p %{buildroot}%{_bindir}
for f in $(find bin -maxdepth 1 -type f \! -name '*.bat' \! -name '*.ico'); do
  cp -p $f %{buildroot}%{_bindir}
done

# Install the shared files
mkdir -p %{buildroot}%{_datadir}/%{name}
cp -a etc plugin %{buildroot}%{_datadir}/%{name}

# Install the noUpdateChecks plugin
cp -p plugins/noUpdateChecks/build/noUpdateChecks.jar %{buildroot}%{_datadir}/%{name}/plugin

# Create /usr/share/findbugs/lib directory containing symlinks to required JARs (bug #1080682)
# List is based on the Class-Path attribute in etc/MANIFEST-findbugs.MF
mkdir -p %{buildroot}%{_datadir}/%{name}/lib
for i in findbugs findbugs-bcel dom4j jaxen objectweb-asm/asm \
   objectweb-asm/asm-commons objectweb-asm/asm-tree jsr-305 \
  jFormatString apache-commons-lang; do
    ln -s %{_javadir}/$i.jar %{buildroot}%{_datadir}/%{name}/lib
done

# Remove now unnecessary build-only manual files so %%doc doesn't get them
rm -f build/doc/manual*.xml build/doc/manual*.xsl

# Install poms
mkdir -p %{buildroot}%{_mavenpomdir}
sed -i 's/3\.0\.0/3\.0\.1/g' %{SOURCE4} %{SOURCE6}
cp %{SOURCE3} JPP-%{name}.pom
%pom_remove_parent JPP-%{name}.pom
cp JPP-%{name}.pom %{buildroot}%{_mavenpomdir}/JPP-%{name}.pom
cp %{SOURCE4} %{buildroot}%{_mavenpomdir}/JPP-%{name}-annotations.pom
cp %{SOURCE6} %{buildroot}%{_mavenpomdir}/JPP.ant-ant-%{name}.pom

# Add depmaps
%add_maven_depmap -a net.sourceforge.findbugs:findbugs JPP-%{name}.pom %{name}.jar
%add_maven_depmap -a net.sourceforge.findbugs:annotations JPP-%{name}-annotations.pom %{name}-annotations.jar
%add_maven_depmap -a net.sourceforge.findbugs:findbugs-ant JPP.ant-ant-%{name}.pom ant/ant-findbugs.jar -f ant

mkdir -p %{buildroot}%{_datadir}/applications
install -D -p -m 644 %{SOURCE10} %{buildroot}%{_datadir}/icons/hicolor/16x16/apps/%{name}.png
install -D -p -m 644 %{SOURCE11} %{buildroot}%{_datadir}/icons/hicolor/32x32/apps/%{name}.png
install -D -p -m 644 %{SOURCE12} %{buildroot}%{_datadir}/icons/hicolor/48x48/apps/%{name}.png
install -D -p -m 644 %{SOURCE13} %{buildroot}%{_datadir}/pixmaps/%{name}.png

%suse_update_desktop_file -i %{name}
%fdupes -s %{buildroot}
%fdupes -s build/doc

%files -f .mfiles
%license licenses/LICENSE.txt
%doc design/DecouplingFromBCEL.txt design/VisitingAndCaching.txt
%doc README.txt "design/eclipse findbugs plugin features.sxw"
%doc design/architecture/architecture.pdf build/doc
%{_bindir}/*
%{_datadir}/%{name}
%dir %{_datadir}/icons/hicolor/
%{_datadir}/icons/hicolor/16x16/apps/findbugs.png
%{_datadir}/icons/hicolor/32x32/apps/findbugs.png
%{_datadir}/icons/hicolor/48x48/apps/findbugs.png
%{_datadir}/applications/*%{name}.desktop
%{_datadir}/pixmaps/%{name}.png

%files -n ant-findbugs -f .mfiles-ant
%license licenses/LICENSE.txt
%config(noreplace) %{_sysconfdir}/ant.d/%{name}

%files javadoc
%{_javadocdir}/*

%files tools
%license licenses/LICENSE.txt
%doc README.tools
%{_javadir}/findbugs-tools.jar

%changelog
* Tue Sep 12 2023 Fridrich Strba <fstrba@suse.com>
- Modified patch:
  * findbugs-javadoc.patch
    + avoid timestamps in javadoc
- Added patch:
  * reproducible-now.patch
    + use timestamp from the SOURCE_DATE_EPOCH environmental
    variable, if it is set
* Sun Sep 29 2019 Fridrich Strba <fstrba@suse.com>
- Remove reference to parent pom, since we don't build using maven.
* Thu Dec 20 2018 Jan Engelhardt <jengelh@inai.de>
- Restore nominal phrase in summary.
* Wed Dec 19 2018 Fridrich Strba <fstrba@suse.com>
- Update to version 3.0.1
  * Build with source/target 7
  * Build against objectweb-asm instead of asm3
- Removed patches:
  * findbugs-1.3.9-build.patch
  * findbugs-1.3.9-jdk9.patch
  * findbugs-asm-version.patch
  * findbugs-jar-filenames.patch
  * findbugs-remove-classpath.patch
- Added patches:
  * findbugs-ant-task-classpath.patch
    + Allow using findbugs even though there is no classpath
    in the jar's manifest
  * findbugs-build.patch
    + Build against the jars in system %%_javadir instead of in
    tarball's lib directory
    + Do not forbid building with Java 8
    + Do not run git while building
  * findbugs-dom4j.patch
    + Add a cast to be able to build with dom4j 2.0
  * findbugs-jdk11.patch
    + Fix incompatible types
  * findbugs-manual.patch
    + Use xsltproc instead of saxon for xslt processing
    + Use the system docbook-xsl-stylesheets
  * findbugs-javadoc.patch
    + Build javadoc with source 1.7 in order to prevent errors due
    to one package name existing in different modules
- Modified patch:
  * findbugs-home.patch
    + Remove Class-Path entry from findbugs.jar manifest;
    use build-classpath instead
    + Simplify shell fragment that determines findbugs_home
* Sun Nov 18 2018 Fridrich Strba <fstrba@suse.com>
- Update the pom files so that they correspond to the distributed
  findbugs version.
- Add pom file for findbugs-ant
- Removed patch:
  * findbugs-1.3.9-pom.patch
    + not needed since the versions correspond now
* Wed Jun 13 2018 fstrba@suse.com
- Depend on asm3 instead of objectweb-asm, since the binaries are
  equivalent
- Modified patches:
  * findbugs-jar-filenames.patch
  * findbugs-remove-classpath.patch
    + replace objectweb-asm with asm3 directories
* Thu May 17 2018 fstrba@suse.com
- Modified patch:
  * findbugs-1.3.9-jdk9.patch
    + Build with java source/target levels 8
* Fri Sep 29 2017 fstrba@suse.com
- Don't condition the maven defines on release version, but on
  _maven_repository being defined
* Mon Sep 18 2017 fstrba@suse.com
- Added patch:
  * findbugs-1.3.9-jdk9.patch
    + Fix build with jdk9
    + Specify java source and target level 1.6
* Fri May 19 2017 pcervinka@suse.com
- New build dependency: javapackages-local
- Fixed requires
- Removed not needed build requirements
- Spec file cleaned
* Sun Aug 23 2015 badshah400@gmail.com
- When building on openSUSE:42, the maven metadata is installed
  as /usr/share/maven-fragments/findbugs instead of
  /usr/share/maven-metadata/findbugs.xml by make install.
* Wed Mar 18 2015 tchvatal@suse.com
- Fix build with new javapackages-tools
* Tue Jul  8 2014 tchvatal@suse.com
- Do not depend on ant-nodeps.
* Mon Jul  7 2014 tchvatal@suse.com
- Use junit not junit4
* Tue Jul  1 2014 tchvatal@suse.com
- Set defattr on files properly.
* Mon Jun 23 2014 tchvatal@suse.com
- Remove unused patch:
  * findbugs-bcel.patch
* Sun Jun 22 2014 schwab@suse.de
- Increase stacksize for ppc as well
* Mon Jan  6 2014 dvaleev@suse.com
- increase stacksize for ppc64le as well.
* Mon Sep  9 2013 tchvatal@suse.com
- Move from jpackage-utils to javapackage-tools
* Wed Sep  4 2013 mvyskocil@suse.com
- Drop useless texlive from BR
* Tue Sep  3 2013 mvyskocil@suse.com
- Rework spec file
  * fixed rpm groups
  * splitted ant task to ant-findbugs
  * use url when possible
  * grab Fedora patches
  * change dependency on findbugs-bcel
  * use new add_maven_depmap
- Patches added
  * findbugs-1.3.9-build.patch
  * findbugs-1.3.9-pom.patch
  * findbugs-asm-version.patch
  * findbugs-home.patch
  * findbugs-jar-filenames.patch
  * findbugs-remove-classpath.patch
- Patches removed
  * findbugs-build_xml.patch
  * findbugs-manifest.patch
* Wed Dec 12 2012 dvaleev@suse.com
- increase stack size for ppc64
* Tue Jun 19 2012 mvyskocil@suse.cz
- build require hicolor-icon-theme to workaround the
  /usr/share/icons/hicolor owning problem
- fix Group according SUSE standards
* Sat Jun 16 2012 andreas.stieger@gmx.de
- fix factory build by adding unpackaged icon directory
* Sun Sep 18 2011 jengelh@medozas.de
- Apply packaging guidelines (remove redundant/obsolete
  tags/sections from specfile, etc.)
* Tue Jul 26 2011 mvyskocil@suse.cz
- fix bnc#708056: add missing objectweb-asm Requires
* Wed Jan 27 2010 mvyskocil@suse.cz
- merged with findbugs-1.3.4-3.jpp5.src.rpm
- removed documentation files with a problematic license (bnc#569639)
* Thu Dec 10 2009 mvyskocil@suse.cz
- refreshed patches
  * findbugs-Project.patch
  * findbugs-build_xml.patch
* Wed Jun  3 2009 mvyskocil@suse.cz
- Initial SUSE packaging from jpackage 5.0
